# DOQUARTUS.tcl
#-- --------------------------------------------------------------
#-- UART Demo Project
#-- Tcl script File for Quartus (Project creation & assignments)
#-- --------------------------------------------------------------
#-- (c) ALSE - http://www.alse-fr.com

# ======================================================
# This version is ready for the NIOS Cyclone 1C20 board
# ======================================================

# ---- Load Quartus II Tcl Project package

package require ::quartus::project
package require ::quartus::flow

set MyProj top_uart

# ---- Introduction

puts "\n==== Project Script (c) ALSE ===="
puts   "     http://www.alse-fr.com\n"

# ---- Check that the right project is open
if {[is_project_open]} {
  if {[string compare $quartus(project) $MyProj]} {
    puts "Error : another project is already opened."
    puts "Please close this project and try again."
    set make_assignments 0
  } else {
    puts "The Top project was already opened..."
  }
} else {
  # Only open if not already open
  if {[project_exists $MyProj]} {
    project_open -cmp $MyProj $MyProj
  } else {
    project_new $MyProj
  }
}

# -- remove the old sof file (if exists)
if [file exists ${MyProj}.sof]  {
  file delete  ${MyProj}.sof
  }


# ---- Make assignments

  # ---- Project files (respect bottom-up order)
  set_global_assignment -name "VHDL_FILE" "../../src/uarts.vhd"
  set_global_assignment -name "VHDL_FILE" "../../src/applic.vhd"
  set_global_assignment -name "VHDL_FILE" "../../src/top_uart.vhd"

  # ---- Compiler Assignments for top_uart
  set_project_settings -cmp $MyProj
  set_global_assignment -name "COMPILATION_LEVEL" "FULL"
  set_global_assignment -name "FAMILY" "CYCLONE"
  set_global_assignment -name "FOCUS_ENTITY_NAME" $MyProj

  set_global_assignment -name "DEVICE" "EP1C20F400C7"

  # ---- Pin assignments

  set_location_assignment -to "CLK"         "Pin_K5"
  set_location_assignment -to "NRST"        "Pin_L14"
  # for console use K16
  set_location_assignment -to "RS232_RX0"   "Pin_C13"
  # for console use M14
  set_location_assignment -to "RS232_TX0"   "Pin_A13"

  # there is no DIPSwitch, so we use SW0... (1 when not pressed)
  set_location_assignment -to "DIPSW\[0\]"  "Pin_W3"


  set_global_assignment   -name RESERVE_ALL_UNUSED_PINS "AS INPUT TRI-STATED"
  set_instance_assignment -name GLOBAL_SIGNAL "GLOBAL CLOCK" -to CLK

  # ---- Timing assignment (Global Fmax)
  set_global_assignment -name fmax_requirement 50MHz

  #---- Commit assignments
  export_assignments
  puts "Assignments done, starting compilation..."

  #---- Compile using ::quartus::flow
  execute_flow -compile

  #  (we have no way in 4.2 to verify automatically that no error occured
  if [file exists ${MyProj}.sof]  {
    puts "\nCompilation apparently suceeded.\nlaunching Programmer."
    exec quartus_pgmw ${MyProj}.sof
  } else {
    puts "\nCompilation apparently FAILED. Inspect the report files (.rpt).\n"
  }


