-- TOP_UART.vhd
-- ----------------------------------------------
--   UART-based Demo Project : Top Level
-- ----------------------------------------------
-- (c) ALSE
-- Author : Bert Cuzeau
-- E_mail : info@alse-fr.com
-- Web    : http://www.alse-fr.com
--
-- Note : can be used in any existing demo boards like
--   Altera NIOS, Insight Spartan2, Xess, Seytronix', etc....
--
-- Set up for standalone synthesis for Insight's Spartan II board.
--  * modify the Generics default value if necessary.
-- To set up the UARTS baud rate values :
--  * modify the UARTS Generic map section (Baud1 & Baud2).
--
-- MAKE SURE YOU set up the BOARD's SIGNALS POLARITY & Clock Frequency

LIBRARY IEEE;
  USE IEEE.std_logic_1164.ALL;

-- ------------------------------------------
    Entity TOP_UART is
-- ------------------------------------------
-- >>>> IMPORTANT : remember to modify Fxtal below to match your board !!!! <<<<<<
    Generic ( Fxtal  : integer  := 60E6;      -- CLK requency, in Hertz (60Mhz=60E6)
              Parity : boolean  := false;     -- word format
              Even   : boolean  := false;     -- kind of parity when used
              Reset_active : std_logic := '0' -- Reset polarity
            );
      Port (     CLK : In    std_logic; -- Global Clock
             Reset_n : In    std_logic; -- Async reset, active @ Reset_active !
           RS232_RX0 : In    std_logic; -- RS232 RX input
           RS232_TX0 : Out   std_logic; -- RS232 TX output
-- Options :
               DIPSW : In    std_logic_vector(0 to 0) -- Baud rate selection
--               RTS : In    std_logic; -- RTS input (or '1')
--               CTS : Out   std_logic  -- CTS output
            );
end TOP_UART;


-- ------------------------------------------
    Architecture FULL of TOP_UART is
-- ------------------------------------------
  constant  Baud1 : integer range 1200 to 921600 := 115200;
  constant  Baud2 : integer range 1200 to 921600 := 19200;

  signal     RSTi : std_logic;
  signal    RxErr : STD_LOGIC;
  signal    RxRDY : STD_LOGIC;
  signal   TxBusy : STD_LOGIC;
  signal LD_SDout : STD_LOGIC;
  signal     iRTS : std_logic;
  signal     Baud : STD_LOGIC;
  signal    SDout : STD_LOGIC_VECTOR (7 downto 0);
  signal     SDin : STD_LOGIC_VECTOR (7 downto 0);
  signal  SDcoded : STD_LOGIC_VECTOR (7 downto 0);

begin

-- Global Reset resynchronized

process (CLK)
begin
  if rising_edge(CLK) then
    RSTi <= Reset_n xor not Reset_active;
  end if;
end process;

-- RS 232 Flow Control signals (when used please modify) >>>>>>>>>> :

--CTS <= '1'; -- permanently enabled

-- Use this when you have the RTS input connected to your FPGA :
-- iRTS <= not RTSFLEX; -- inversion may or may not be necessary.

-- Use this when you have no hardware flow control :
iRTS <= '1';  -- permanently enabled

-- <<<<<<<<<<<<<<<<<<

Baud <= DIPSW(0);


-- (direct) Instanciations

i_APPLIC : entity work.APPLIC
      Port Map ( CLK    => CLK,
                 RST    => RSTi,
                 RTS    => iRTS,
                 RxErr  => RxErr,
                 RxRDY  => RxRDY,
                 SDin   => SDin,
                 TxBusy => TxBusy,
                 SDout  => SDout,
                 LD_SDout=> LD_SDout );

i_UARTS : entity work.UARTS
   Generic map ( Fxtal  => Fxtal,
                 Parity => Parity,
                 Even   => Even,
                 Baud1  => Baud1,    -- <<<<< BaudRate # 1 <<<<<<<
                 Baud2  => Baud2 )   -- BaudRate # 2 (same here)
   Port Map    ( CLK    => CLK,
                 RST    => RSTi,
                 Baud   => Baud,
                 Din    => SDout,
                 LD     => LD_SDout,
                 Rx     => RS232_RX0,
                 Dout   => SDin,
                 RxErr  => RxErr,
                 RxRDY  => RxRDY,
                 Tx     => RS232_TX0,
                 TxBusy => TxBusy );

end FULL;
